<?php
namespace Barn2\Plugin\WC_Lead_Time\Admin\Wizard\Steps;

use Barn2\Plugin\WC_Lead_Time\Dependencies\Setup_Wizard\Api;
use Barn2\Plugin\WC_Lead_Time\Dependencies\Setup_Wizard\Step;

class Display extends Step {

	/**
	 * {@inheritdoc}
	 */
	public function __construct() {
		$this->set_id( 'display' );
		$this->set_name( esc_html__( 'Display', 'woocommerce-lead-time' ) );
		$this->set_title( esc_html__( 'Where to show product lead times', 'woocommerce-lead-time' ) );
		$this->set_description( esc_html__( 'First, decide where on the site to display the lead time information about each product.', 'woocommerce-lead-time' ) );
	}

	/**
	 * {@inheritdoc}
	 */
	public function setup_fields() {
		$fields = [];

		$fields['display_heading'] = [
			'type'  => 'heading',
			'label' => esc_html__( 'Display lead times on', 'woocommerce-lead-time' ),
			'style' => [
				'fontSize' => '13px'
			]
		];

		$fields['wclt_display_on_single_product'] = [
			'type'    => 'checkbox',
			'label'   => esc_html__( 'Single product page', 'woocommerce-lead-time' ),
			'value'   => get_option( 'wclt_display_on_single_product', 'yes' ) === 'yes',
			'classes' => [ 'no-margin-checkbox' ]
		];

		$fields['wclt_display_on_cart_item'] = [
			'type'    => 'checkbox',
			'label'   => esc_html__( 'Cart', 'woocommerce-lead-time' ),
			'value'   => get_option( 'wclt_display_on_cart_item' ) === 'yes',
			'classes' => [ 'no-margin-checkbox' ]
		];

		$fields['wclt_display_on_checkout_item'] = [
			'type'    => 'checkbox',
			'label'   => esc_html__( 'Checkout', 'woocommerce-lead-time' ),
			'value'   => get_option( 'wclt_display_on_checkout_item' ) === 'yes',
			'classes' => [ 'no-margin-checkbox' ]
		];

		$fields['wclt_display_on_shop'] = [
			'type'    => 'checkbox',
			'label'   => esc_html__( 'Shop/category pages', 'woocommerce-lead-time' ),
			'value'   => get_option( 'wclt_display_on_shop' ) === 'yes',
			'classes' => [ 'no-margin-checkbox' ]
		];

		$fields['wclt_display_on_order_item'] = [
			'type'  => 'checkbox',
			'label' => esc_html__( 'Order details (e.g. emails and the order details page)', 'woocommerce-lead-time' ),
			'value' => get_option( 'wclt_display_on_order_item' ) === 'yes',
		];

		$fields['wclt_text_color'] = [
			'type'  => 'color',
			'label' => esc_html__( 'Lead time text color', 'woocommerce-lead-time' ),
			'value' => get_option( 'wclt_text_color', '#60646c' ),
		];

		return $fields;
	}

	/**
	 * {@inheritdoc}
	 */
	public function submit( array $values ) {

		$checkboxes = [
			'wclt_display_on_single_product',
			'wclt_display_on_cart_item',
			'wclt_display_on_checkout_item',
			'wclt_display_on_shop',
			'wclt_display_on_order_item'
		];

		foreach ( $checkboxes as $checkbox_key ) {
			if ( isset( $values[ $checkbox_key ] ) ) {
				$value = $values[ $checkbox_key ];
				update_option( $checkbox_key, $value === '1' || $value === true || $value === 'true' ? 'yes' : 'no' );
			}
		}

		update_option( 'wclt_text_color', $values['wclt_text_color'] );

		return Api::send_success_response();
	}

}
